# Generated by Django 3.1.7 on 2021-03-14 11:24

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('id_trust', '0005_auto_20210228_1729'),
    ]

    operations = [
        migrations.CreateModel(
            name='Journey',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_time', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.AddField(
            model_name='dialog',
            name='journey',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='id_trust.journey'),
            preserve_default=False,
        ),
    ]
